@@ -13,10 +13,11 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 """
+
 import requests
 
-from pynetbox.core.query import Request
 from pynetbox.core.app import App, PluginsApp
+from pynetbox.core.query import Request
 from pynetbox.core.response import Record
 
 
@@ -27,15 +28,16 @@ class Api:
     you can specify which app and endpoint you wish to interact with.
 
     Valid attributes currently are:
-        * dcim
-        * ipam
         * circuits
-        * secrets (on NetBox 2.11 and older)
-        * tenancy
+        * core (NetBox 3.5+)
+        * dcim
         * extras
+        * ipam
+        * tenancy
+        * users
         * virtualization
-        * users (since NetBox 2.9)
-        * wireless (since NetBox 3.1)
+        * vpn (NetBox 3.7+)
+        * wireless
 
     Calling any of these attributes will return
     :py:class:`.App` which exposes endpoints as attributes.
@@ -50,13 +52,8 @@ class Api:
     :param str url: The base URL to the instance of NetBox you
         wish to connect to.
     :param str token: Your NetBox token.
-    :param str,optional private_key_file: The path to your private
-        key file. (Usable only on NetBox 2.11 and older)
-    :param str,optional private_key: Your private key. (Usable only on NetBox 2.11 and older)
     :param bool,optional threading: Set to True to use threading in ``.all()``
         and ``.filter()`` requests.
-    :raises ValueError: If *private_key* and *private_key_file* are both
-        specified.
     :raises AttributeError: If app doesn't exist.
     :Examples:
 
@@ -73,36 +70,22 @@ class Api:
         self,
         url,
         token=None,
-        private_key=None,
-        private_key_file=None,
         threading=False,
     ):
-        if private_key and private_key_file:
-            raise ValueError(
-                '"private_key" and "private_key_file" cannot be used together.'
-            )
         base_url = "{}/api".format(url if url[-1] != "/" else url[:-1])
         self.token = token
-        self.private_key = private_key
-        self.private_key_file = private_key_file
         self.base_url = base_url
-        self.session_key = None
         self.http_session = requests.Session()
         self.threading = threading
-
-        if self.private_key_file:
-            with open(self.private_key_file, "r") as kf:
-                private_key = kf.read()
-                self.private_key = private_key
-
-        self.dcim = App(self, "dcim")
-        self.ipam = App(self, "ipam")
         self.circuits = App(self, "circuits")
-        self.secrets = App(self, "secrets")
-        self.tenancy = App(self, "tenancy")
+        self.core = App(self, "core")
+        self.dcim = App(self, "dcim")
         self.extras = App(self, "extras")
-        self.virtualization = App(self, "virtualization")
+        self.ipam = App(self, "ipam")
+        self.tenancy = App(self, "tenancy")
         self.users = App(self, "users")
+        self.virtualization = App(self, "virtualization")
+        self.vpn = App(self, "vpn")
         self.wireless = App(self, "wireless")
         self.plugins = PluginsApp(self)
 
@@ -156,8 +139,6 @@ class Api:
     def status(self):
         """Gets the status information from NetBox.
 
-        Available in NetBox 2.10.0 or newer.
-
         :Returns: Dictionary as returned by NetBox.
         :Raises: :py:class:`.RequestError` if the request is not successful.
         :Example:
@@ -192,8 +173,6 @@ class Api:
         """Creates an API token using a valid NetBox username and password.
         Saves the created token automatically in the API object.
 
-        Requires NetBox 3.0.0 or newer.
-
         :Returns: The token as a ``Record`` object.
         :Raises: :py:class:`.RequestError` if the request is not successful.
 
