@@ -1,16 +1,14 @@
+import atexit
 import os
-
-from packaging import version
 import subprocess as subp
 import time
-import yaml
 from http.client import RemoteDisconnected
 
-import atexit
-import pynetbox
 import pytest
 import requests
+import yaml
 
+import pynetbox
 
 DOCKER_PROJECT_PREFIX = "pytest_pynetbox"
 
@@ -28,8 +26,12 @@ def get_netbox_docker_version_tag(netbox_version):
     """
     major, minor = netbox_version.major, netbox_version.minor
 
-    if (major, minor) == (3, 3):
-        tag = "2.2.0"
+    if (major, minor) == (3, 6):
+        tag = "2.7.0"
+    elif (major, minor) == (3, 7):
+        tag = "2.8.0"
+    elif (major, minor) == (4, 0):
+        tag = "2.9.1"
     else:
         raise NotImplementedError(
             "Version %s is not currently supported" % netbox_version
@@ -49,7 +51,7 @@ def git_toplevel():
     try:
         subp.check_call(["which", "git"])
     except subp.CalledProcessError:
-        pytest.skip(msg="git executable was not found on the host")
+        pytest.skip(reason="git executable was not found on the host")
     return (
         subp.check_output(["git", "rev-parse", "--show-toplevel"])
         .decode("utf-8")
@@ -74,7 +76,7 @@ def netbox_docker_repo_dirpaths(pytestconfig, git_toplevel):
     try:
         subp.check_call(["which", "docker"])
     except subp.CalledProcessError:
-        pytest.skip(msg="docker executable was not found on the host")
+        pytest.skip(reason="docker executable was not found on the host")
     netbox_versions_by_repo_dirpaths = {}
     for netbox_version in pytestconfig.option.netbox_versions:
         repo_version_tag = get_netbox_docker_version_tag(netbox_version=netbox_version)
@@ -228,7 +230,7 @@ def docker_compose_file(pytestconfig, netbox_docker_repo_dirpaths):
             )
             compose_data["networks"] = {docker_network_name: {}}
             # https://docs.docker.com/compose/compose-file/compose-file-v3/#network-configuration-reference
-            if compose_data["version"] >= "3.5":
+            if "version" not in compose_data or compose_data["version"] >= "3.5":
                 compose_data["networks"][docker_network_name][
                     "name"
                 ] = docker_network_name
@@ -249,6 +251,14 @@ def docker_compose_file(pytestconfig, netbox_docker_repo_dirpaths):
                         "netboxcommunity/netbox:v%s" % netbox_version
                     )
 
+                    new_services[new_service_name]["environment"] = {
+                        "SKIP_SUPERUSER": "false",
+                        "SUPERUSER_API_TOKEN": "0123456789abcdef0123456789abcdef01234567",
+                        "SUPERUSER_EMAIL": "admin@example.com",
+                        "SUPERUSER_NAME": "admin",
+                        "SUPERUSER_PASSWORD": "admin",
+                    }
+
                 if service_name == "netbox":
                     # ensure the netbox container listens on a random port
                     new_services[new_service_name]["ports"] = ["8080"]
@@ -342,7 +352,7 @@ def docker_compose_file(pytestconfig, netbox_docker_repo_dirpaths):
 
 
 def netbox_is_responsive(url):
-    """Chack if the HTTP service is up and responsive."""
+    """Check if the HTTP service is up and responsive."""
     try:
         response = requests.get(url)
         if response.status_code == 200:
@@ -468,14 +478,14 @@ def device_type(api, manufacturer):
 
 
 @pytest.fixture(scope="session")
-def device_role(api):
-    device_role = api.dcim.device_roles.create(
+def role(api):
+    role = api.dcim.device_roles.create(
         name="test-device-role",
         slug="test-device-role",
         color="000000",
     )
-    yield device_role
-    device_role.delete()
+    yield role
+    role.delete()
 
 
 def pytest_generate_tests(metafunc):
