@@ -2,14 +2,14 @@ import unittest
 from unittest.mock import patch
 
 import pynetbox
-from .util import Response
 
+from .util import Response
 
 api = pynetbox.api("http://localhost:8000")
 
 nb_app = api.wireless
 
-HEADERS = {"accept": "application/json;"}
+HEADERS = {"accept": "application/json"}
 
 
 class Generic:
